emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 81656ad: Fix auto-filling regression


From: Tom Tromey
Subject: [Emacs-diffs] master 81656ad: Fix auto-filling regression
Date: Wed, 9 Aug 2017 18:09:02 -0400 (EDT)

branch: master
commit 81656add8117e8d1b7faab18b330d0706462b433
Author: Tom Tromey <address@hidden>
Commit: Tom Tromey <address@hidden>

    Fix auto-filling regression
    
    Bug#28003
    * lisp/newcomment.el (comment-indent-new-line): Check
    comment-auto-fill-only-comments.  Reverts earlier change.
    * lisp/simple.el (internal-auto-fill): Call auto-fill-function, not
    do-auto-fill.
---
 lisp/newcomment.el | 5 +++--
 lisp/simple.el     | 2 +-
 2 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/lisp/simple.el b/lisp/simple.el
index 9838f16..933ffc5 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -7243,7 +7243,7 @@ unless optional argument SOFT is non-nil."
   (when (or (not comment-start)
             (not comment-auto-fill-only-comments)
             (nth 4 (syntax-ppss)))
-    (do-auto-fill)))
+    (funcall auto-fill-function)))
 
 (defvar normal-auto-fill-function 'do-auto-fill
   "The function to use for `auto-fill-function' if Auto Fill mode is turned on.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/newcomment.el b/lisp/newcomment.el
index e3ee4df..8772b523 100644
--- a/lisp/newcomment.el
+++ b/lisp/newcomment.el
@@ -1382,9 +1382,10 @@ unless optional argument SOFT is non-nil."
   (interactive)
   (comment-normalize-vars t)
   (let (compos comin)
     ;; If we are not inside a comment don't do anything (unless no
     ;; comment syntax is defined).
     (unless (and comment-start
+                comment-auto-fill-only-comments
                 (not (called-interactively-p 'interactive))
                 (not (save-excursion
                        (prog1 (setq compos (comment-beginning))
@@ -1382,9 +1382,10 @@ unless optional argument SOFT is non-nil."
   (comment-normalize-vars t)
   (let (compos comin)
-    ;; If we are not inside a comment don't do anything (unless no
-    ;; comment syntax is defined).
+    ;; If we are not inside a comment and we only auto-fill comments,
+    ;; don't do anything (unless no comment syntax is defined).
     (unless (and comment-start